ResolvedPolicy

Struct ResolvedPolicy 

pub struct ResolvedPolicy {
    pub requested_tier: LayoutTier,
    pub effective_tier: LayoutTier,
    pub degraded: bool,
    pub objective: ParagraphObjective,
    pub vertical: VerticalMetrics,
    pub justification: JustificationControl,
    pub use_hyphenation: bool,
    pub use_optimal_breaking: bool,
    pub line_height_subpx: u32,
}
Fully-resolved layout configuration ready for use by the layout engine.

All three subsystem configs are populated and compatible with the available runtime capabilities.

Fields

requested_tier: LayoutTier

What the user originally requested.

effective_tier: LayoutTier

What was actually activated (may differ if degraded).

degraded: bool

Whether degradation occurred.

objective: ParagraphObjective

Knuth-Plass line-break tuning.

vertical: VerticalMetrics

Resolved vertical metrics (leading, spacing, grid).

justification: JustificationControl

Justification controls (stretch/shrink/penalties).

use_hyphenation: bool

Whether hyphenation should be used for line breaking.

use_optimal_breaking: bool

Whether optimal (Knuth-Plass) breaking should be used. False = greedy wrapping.

line_height_subpx: u32

Line height in sub-pixel units.

Implementations

Source

impl ResolvedPolicy

pub fn is_justified(&self) -> bool

Whether justification (space stretching) is active.

pub fn feature_summary(&self) -> Vec<&'static str>

Human-readable summary of what features are active.