Rope

Struct Rope 

pub struct Rope { /* private fields */ }
Rope-backed text storage.

Implementations

Source

impl Rope

pub fn new() -> Self

Create an empty rope.

pub fn from_text(s: &str) -> Self

Create a rope from a string slice.

This is a convenience method. You can also use .parse() or From<&str>.

pub fn len_bytes(&self) -> usize

Total length in bytes.

pub fn len_chars(&self) -> usize

Total length in Unicode scalar values.

pub fn len_lines(&self) -> usize

Total number of lines (newline count + 1).

pub fn is_empty(&self) -> bool

Returns true if the rope is empty.

pub fn line(&self, idx: usize) -> Option<Cow<'_, str>>

Get a line by index.

pub fn lines(&self) -> impl Iterator<Item = Cow<'_, str>> + '_

Iterate over all lines.

pub fn slice<R>(&self, range: R) -> Cow<'_, str>
where R: RangeBounds<usize>,

Get a slice of the rope by character range.

pub fn insert(&mut self, char_idx: usize, text: &str)

Insert text at a character index.

pub fn insert_grapheme(&mut self, grapheme_idx: usize, text: &str)

Insert text at a grapheme index.

pub fn remove<R>(&mut self, range: R)
where R: RangeBounds<usize>,

Remove a character range.

pub fn remove_grapheme_range<R>(&mut self, range: R)
where R: RangeBounds<usize>,

Remove a grapheme range.

pub fn replace(&mut self, text: &str)

Replace the entire contents.

pub fn append(&mut self, text: &str)

Append text to the end.

pub fn clear(&mut self)

Clear all content.

pub fn char_to_byte(&self, char_idx: usize) -> usize

Convert a character index to a byte index.

pub fn byte_to_char(&self, byte_idx: usize) -> usize

Convert a byte index to a character index.

pub fn char_to_line(&self, char_idx: usize) -> usize

Convert a character index to a line index.

pub fn line_to_char(&self, line_idx: usize) -> usize

Get the character index at the start of a line.

pub fn byte_to_line_col(&self, byte_idx: usize) -> (usize, usize)

Convert a byte index to (line, column) in characters.

pub fn line_col_to_byte(&self, line_idx: usize, col: usize) -> usize

Convert (line, column) in characters to a byte index.

pub fn chars(&self) -> impl Iterator<Item = char> + '_

Iterate over all characters.

pub fn graphemes(&self) -> Vec<String>

Return all graphemes as owned strings.

pub fn grapheme_count(&self) -> usize

Count grapheme clusters.