ControlCode

Enum ControlCode 

pub enum ControlCode {
    CarriageReturn,
    LineFeed,
    Bell,
    Backspace,
    Tab,
    Home,
    ClearToEndOfLine,
    ClearLine,
}
Control codes that can be carried by a segment.

Control segments do not consume display width and are used for non-textual actions like cursor movement or clearing.

Variants



CarriageReturn

Carriage return (move to start of line)



LineFeed

Line feed (move to next line)



Bell

Bell (audible alert)



Backspace

Backspace



Tab

Tab



Home

Home (move to start of line, used in some contexts)



ClearToEndOfLine

Clear to end of line



ClearLine

Clear line

Implementations

Source

impl ControlCode

pub const fn is_newline(&self) -> bool

Whether this control code should cause a line break.

pub const fn is_cr(&self) -> bool

Whether this control code is a carriage return.