pub fn join_lines<'a>(lines: &SegmentLines<'a>) -> Vec<Segment<'a>>Expand description
Join lines into a flat sequence of segments with newlines between.
pub fn join_lines<'a>(lines: &SegmentLines<'a>) -> Vec<Segment<'a>>Join lines into a flat sequence of segments with newlines between.