pub struct FontId(pub u32);Expand description
Opaque identifier for a font face within the application.
The mapping from FontId to actual font data is managed by the caller.
The shaping layer treats this as an opaque discriminant for cache keying.
Tuple Fields
0: u32Trait Implementations
Sourceimpl Ord for FontId
impl Ord for FontId
Sourceimpl PartialOrd for FontId
impl PartialOrd for FontId
impl Copy for FontId
impl Eq for FontId
impl StructuralPartialEq for FontId