pub struct ParagraphSpacing {
pub before_subpx: u32,
pub after_subpx: u32,
}Expand description
Configurable space before and after paragraphs.
Fields
before_subpx: u32Space before the first line of a paragraph (sub-pixel units).
after_subpx: u32Space after the last line of a paragraph (sub-pixel units).
Implementations