TextView

Struct TextView 

pub struct TextView { /* private fields */ }
A scrollable, wrapped view over a text buffer.

Implementations

Source

impl TextView

pub fn new(text: impl Into<Rope>, width: usize, wrap: WrapMode) -> Self

Build a view from raw text, wrap mode, and viewport width.

pub fn set_text(&mut self, text: impl Into<Rope>)

Replace the text and recompute layout.

pub fn set_wrap(&mut self, wrap: WrapMode)

Update wrap mode and recompute layout.

pub fn set_width(&mut self, width: usize)

Update viewport width and recompute layout.

pub const fn wrap_mode(&self) -> WrapMode

Current wrap mode.

pub const fn width(&self) -> usize

Current viewport width used for wrapping.

pub const fn source_line_count(&self) -> usize

Number of logical (source) lines in the text.

pub fn virtual_line_count(&self) -> usize

Number of virtual (wrapped) lines.

pub const fn max_width(&self) -> usize

Maximum display width across all virtual lines.

pub fn lines(&self) -> &[ViewLine]

Access all virtual lines.

pub fn source_to_virtual(&self, source_line: usize) -> Option<usize>

Map a source line index to its first virtual line index.

pub fn virtual_to_source(&self, virtual_line: usize) -> Option<usize>

Map a virtual line index to its source line index.

pub fn clamp_scroll(&self, scroll_y: usize, viewport_height: usize) -> usize

Clamp scroll position to a valid range for the given viewport height.

pub fn max_scroll(&self, viewport_height: usize) -> usize

Maximum scroll offset for the given viewport height.

pub fn visible_range( &self, scroll_y: usize, viewport_height: usize, ) -> Range<usize>

Compute the visible virtual line range for a scroll offset + viewport height.

pub fn visible_lines( &self, scroll_y: usize, viewport_height: usize, ) -> &[ViewLine]

Get the visible virtual lines for a scroll offset + viewport height.

pub fn scroll_to_line( &self, source_line: usize, viewport_height: usize, ) -> Option<usize>

Scroll so the given source line is at the top of the viewport. Returns None if the source line doesn’t exist.

pub fn scroll_to_top(&self) -> usize

Scroll to the top of the view.

pub fn scroll_to_bottom(&self, viewport_height: usize) -> usize

Scroll to the bottom of the view.

pub fn scroll_by_lines( &self, scroll_y: usize, delta: isize, viewport_height: usize, ) -> usize

Scroll by a line delta (positive or negative).

pub fn scroll_by_pages( &self, scroll_y: usize, pages: isize, viewport_height: usize, ) -> usize

Scroll by a page delta (positive or negative).