pub struct Doorkeeper { /* private fields */ }Expand description
1-bit Bloom filter used as a doorkeeper to filter one-hit wonders.
On first access within an epoch, the doorkeeper sets a bit. Only on the second access does the item get promoted to the Count-Min Sketch. The doorkeeper is cleared whenever the CMS resets (halves).
Implementations
Sourceimpl Doorkeeper
impl Doorkeeper
Sourcepub fn with_defaults() -> Self
pub fn with_defaults() -> Self
Create a doorkeeper with the default size (2048 bits).
Sourcepub fn check_and_set(&mut self, hash: u64) -> bool
pub fn check_and_set(&mut self, hash: u64) -> bool
Check if a key has been seen. Returns true if the bit was already set.