pub enum JustifyMode {
Left,
Right,
Center,
Full,
Distributed,
}Expand description
Text alignment mode.
Variants
Left
Left-aligned (ragged right). No space stretching.
Right
Right-aligned (ragged left).
Center
Centered text.
Full
Fully justified: spaces are stretched/shrunk to fill the line width. The last line of each paragraph is left-aligned (TeX default).
Distributed
Distributed justification: like Full, but the last line is also justified (CJK convention).
Implementations
Sourceimpl JustifyMode
impl JustifyMode
Sourcepub const fn requires_justification(&self) -> bool
pub const fn requires_justification(&self) -> bool
Whether this mode requires space modulation (stretch/shrink).
Sourcepub const fn justify_last_line(&self) -> bool
pub const fn justify_last_line(&self) -> bool
Whether the last line of a paragraph should be justified.