pub struct TierFeatures {Show 14 fields
pub tier: LayoutTier,
pub shaped_text: bool,
pub terminal_fallback: bool,
pub optimal_breaking: bool,
pub hyphenation: bool,
pub justification: bool,
pub tracking: bool,
pub baseline_grid: bool,
pub paragraph_spacing: bool,
pub first_line_indent: bool,
pub width_cache: bool,
pub shaping_cache: bool,
pub incremental_diff: bool,
pub subcell_spacing: bool,
}Expand description
Feature toggles for a quality tier.
Each flag indicates whether a subsystem feature is active at this tier. Features are monotonically enabled: if a feature is on at tier T, it is also on at every tier above T.
Fields
tier: LayoutTierWhich tier these features apply to.
shaped_text: boolUse the shaped text path (HarfBuzz/rustybuzz) when available.
terminal_fallback: boolUse the terminal (ClusterMap) fallback path.
optimal_breaking: boolUse Knuth-Plass optimal line breaking.
hyphenation: boolUse hyphenation for line breaking.
justification: boolEnable full justification (stretch/shrink word spaces).
tracking: boolEnable inter-character tracking.
baseline_grid: boolActivate baseline grid snapping.
paragraph_spacing: boolApply paragraph spacing.
first_line_indent: boolApply first-line indent.
width_cache: boolUse the width cache.
shaping_cache: boolUse the shaping cache.
incremental_diff: boolUse incremental (dirty-region) diff.
subcell_spacing: boolUse sub-cell spacing (1/256 cell precision).
Implementations
Sourceimpl TierFeatures
impl TierFeatures
Sourcepub fn active_list(&self) -> Vec<&'static str>
pub fn active_list(&self) -> Vec<&'static str>
Human-readable list of active features.