ParagraphSpacing

Struct ParagraphSpacing 

pub struct ParagraphSpacing {
    pub before_subpx: u32,
    pub after_subpx: u32,
}
Configurable space before and after paragraphs.

Fields

before_subpx: u32

Space before the first line of a paragraph (sub-pixel units).

after_subpx: u32

Space after the last line of a paragraph (sub-pixel units).

Implementations

Source

impl ParagraphSpacing

pub const NONE: Self

No extra paragraph spacing.

pub fn one_line(line_height_subpx: u32) -> Self

One full line of spacing between paragraphs (at given line height).

pub fn half_line(line_height_subpx: u32) -> Self

Half-line spacing between paragraphs.

pub const fn custom(before: u32, after: u32) -> Self

Custom spacing in sub-pixel units.

pub const fn total(&self) -> u32

Total paragraph overhead (before + after) in sub-pixel units.